==> Smdn.Formats.Mime-0.15.tar.bz2: Smdn.Formats.Mime-0.15/Smdn.Formats.Mime/Smdn.Formats.Mime/MimeHeaderFragment.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2009 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Text;

namespace Smdn.Formats.Mime {
  public class MimeHeaderFragment : IHeaderFieldBody {
    public string Value {
      get; private set;
    }

    public MimeHeaderEncoding Encoding {
      get; private set;
    }

    public Encoding Charset {
      get; private set;
    }

    public MimeHeaderFragment(string @value)
      : this(@value, MimeHeaderEncoding.None, Charsets.ISO8859_1)
    {
    }

    public MimeHeaderFragment(string @value, MimeHeaderEncoding encoding, Encoding charset)
    {
      if (@value == null)
        throw new ArgumentNullException("value");

      this.Value = @value;
      this.Encoding = encoding;
      this.Charset = charset;
    }

    public override string ToString()
    {
      return Value;
    }
  }
}

==> Smdn.Formats.Mime-0.20.tar.bz2: Smdn.Formats.Mime-0.20/Smdn.Formats.Mime/Smdn.Formats.Mime/MimeHeaderFragment.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Text;

namespace Smdn.Formats.Mime {
  public class MimeHeaderFragment : IHeaderFieldBody {
    public string Value {
      get; private set;
    }

    public MimeEncodingMethod Encoding {
      get; private set;
    }

    public Encoding Charset {
      get; private set;
    }

    public MimeHeaderFragment(string @value)
      : this(@value, MimeEncodingMethod.None, Charsets.ISO8859_1)
    {
    }

    public MimeHeaderFragment(string @value, MimeEncodingMethod encoding, Encoding charset)
    {
      if (@value == null)
        throw new ArgumentNullException("value");

      this.Value = @value;
      this.Encoding = encoding;
      this.Charset = charset;
    }

    public override string ToString()
    {
      return Value;
    }
  }
}
